aboutsummaryrefslogtreecommitdiffstats
path: root/components/layout/context.rs
diff options
context:
space:
mode:
Diffstat (limited to 'components/layout/context.rs')
-rw-r--r--components/layout/context.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/components/layout/context.rs b/components/layout/context.rs
index 4f2cf89de2e..f3db3d80a01 100644
--- a/components/layout/context.rs
+++ b/components/layout/context.rs
@@ -82,8 +82,8 @@ pub struct SharedLayoutContext {
/// A channel for the image cache to send responses to.
pub image_cache_sender: ImageCacheChan,
- /// The current screen size.
- pub screen_size: Size2D<Au>,
+ /// The current viewport size.
+ pub viewport_size: Size2D<Au>,
/// Screen sized changed?
pub screen_size_changed: bool,